// The following stata code is used for Hong and Lee(2016).
// "data0.dta" contains all the variables used for regressions in the paper.
// "quantile_regression.dta" contains the estimated coefficients, standard errors and 95% confidence intervals 
// for QR and IVQR regressions, which are summarized in Figures 2 and 3, and Appendix Figure 2. 
// Quantile regressions were conducted on Matlab and Stata. Their codes and data are zipped into "IVQR_estimation.zip".

log using Result_Hong_and_Lee_2016, smcl replace

***************************************************************
* Table 1: Summary Statistics of Own and Peer Characteristics *
***************************************************************
set more off
use data0, clear

*Mean and SD
sum final mid syear sex srow sidecol econ bus humsoc nateng retake exch nopair
sum pairfinal pairmid navgfinal1_pair navgmid1_pair hetsyear1 hetsex1 if nopair == 0
sum tgpa if misstgpa == 0
sum ptgpa if missptgpa == 0 & nopair == 0

*Correlation Coefficient with Own Midterm Score
pwcorr mid final mid syear sex srow sidecol econ bus humsoc nateng retake exch nopair, sig
pwcorr mid pairfinal pairmid navgfinal1_pair navgmid1_pair hetsyear1 hetsex1 if nopair==0, sig
pwcorr mid tgpa if misstgpa==0, sig
pwcorr mid ptgpa if missptgpa==0 & nopair == 0, sig

*Correlation Coefficient with Own Final Score
pwcorr final mid syear sex srow sidecol econ bus humsoc nateng retake exch nopair, sig
pwcorr final pairfinal pairmid navgfinal1_pair navgmid1_pair hetsyear1 hetsex1 if nopair==0, sig
pwcorr final tgpa if misstgpa==0, sig
pwcorr final ptgpa if missptgpa==0 & nopair == 0, sig

*******************************************************************************
* Table 2: Estimates of the Effect of Pair's Midterm Score on Own Final Score *
*******************************************************************************
set more off
use data0, clear
local control1 "mid srow sidecol syear sex retake exch bus humsoc nateng"
local control2 "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"

*(1): Without PE
areg final `control1', robust absorb(class) cluster(class)
outreg2 using table2.xls, replace excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("w/o peer effect")

*(2): Class FE
areg final `control2', robust absorb(class) cluster(class)
outreg2 using table2.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("w/ peer effect")

*(3): Row-by-Class FE
areg final `control2', robust absorb(class_srow) cluster(class_srow)
outreg2 using table2.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("row by class FE")

*(4): Students with pair
areg final `control2' if nopair == 0, robust absorb(class) cluster(class)
outreg2 using table2.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("with pair")

*(5): Adding tier-two peers
areg final `control2' navgmid2, robust absorb(class) cluster(class)
outreg2 using table2.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("tier two") ///
sortvar(pairmid nopair navgmid1_pair hetsyear1 hetsex1 navgmid2 mid syear sex srow normcol  sidecol bus humsoc nateng retake exch)

*****************************************************************
* Table 3: Instrumental Variable (IV) Estimates of Peer Effects *
*****************************************************************
set more off
use data0, clear
local control1 "tgpa ptgpa misstgpa missptgpa navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control2 "navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control3 "navgmid1_pair hetsex1 hetsyear1 sidecol syear sex retake exch bus humsoc nateng nopair"
local ivs "tgpa ptgpa misstgpa missptgpa"

*(1): Class FE
* Panel A
tsset class classentry
xtreg final `control1', robust cluster(class) fe 
outreg2 using table3.xls, replace excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("reduced")
* Panel B
xi i.class
ivreg2 final (mid pairmid = `ivs') `control2' _Ic*, robust cluster(class)
outreg2 using table3.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("iv")
* Panel B's first stage result
xtivreg2 final (mid pairmid = `ivs') `control2', robust cluster(class) fe first

*(2): Row-by-Class FE
* Paenl A
sort class_srow entry
tsset class_srow classentry1
xtreg final `control1', robust cluster(class_srow) fe
outreg2 using table3.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("reduced")
* Panel B
xi i.class_srow, noomit
ivreg2 final (mid pairmid = `ivs') `control3'  _Iclass_sro_12 - _Iclass_sro_418 , robust cluster(class_srow)
outreg2 using table3.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("iv")
* Panel B's first stage result
xtivreg2 final (mid pairmid = `ivs') `control2', robust cluster(class_srow) fe first

*(3): Students with pair
* Panel A
tsset class classentry
xtreg final `control1' if nopair == 0, robust cluster(class) fe
outreg2 using table3.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("reduced")
* Paenl B
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if nopair == 0, robust cluster(class)
outreg2 using table3.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("ivs")
* Panel B's first stage result
xtivreg2 final (mid pairmid = `ivs') `control2' if nopair == 0, robust cluster(class) fe first

*(4): Adding tier-two peers
* Panel A
tsset class classentry
xtreg final `control1' navgmid2, robust cluster(class) fe
outreg2 using table3.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("reduced")
* Panel B
xi: ivreg2 final (mid pairmid = `ivs') `control2' navgmid2 i.class, robust cluster(class)
outreg2 using table3.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("ivs") ///
sortvar(ptgpa tgpa pairmid nopair navgmid1_pair hetsyear1 hetsex1 navgmid2 mid syear sex srow normcol  sidecol bus humsoc nateng retake exch)
* Panel B's first stage result
xtivreg2 final (mid pairmid = `ivs') `control2' navgmid2, robust cluster(class) fe first

******************************************************************
* Table 4: Peer Effects among Pairs without Previous Interaction *
******************************************************************
*(1) Exclusing students in classes with high correlations between own and pair's GPA
set more off
estimates clear
use data0, clear
local control1 "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control2 "navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local ivs "tgpa ptgpa misstgpa missptgpa"
* Panel A: OLS
areg final `control1' if nopcorr == 1, robust absorb(class) cluster(class)
outreg2 using table4_ols.xls, replace excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4)
* Panel B: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2' if nopcorr == 1, robust cluster(class) fe first
outreg2 using table4_iv.xls, replace excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4)
* Panel B: To get the coefficient of constant term
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if nopcorr == 1, robust cluster(class)

*(2) Excluding pairs who took any same classes before the semester
set more off
use data0, clear
local control1 "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control2 "navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local ivs "tgpa ptgpa misstgpa missptgpa"

* Panel A: OLS
areg final `control1' if num_metbefore == 0, robust absorb(class) cluster(class)
outreg2 using table4_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4)
* Panel B: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2' if num_metbefore == 0, robust cluster(class) fe first
outreg2 using table4_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4)
* Panel B: To get the coefficient of constant term
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if num_metbefore == 0, robust cluster(class)

*(3) Excluding pairs who were paired in any classes before the semester
set more off
use data0, clear
unique id pairid
sort id pairid year semester class
by id pairid: gen pair_entry = _n
replace pair_entry = . if pairid == .

duplicates tag id pairid, gen(pair_num)
order id pairid pair_entry pair_num year semester
keep if pairid == . | (pair_entry == pair_num + 1)

local control1 "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control2 "navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local ivs "tgpa ptgpa misstgpa missptgpa"

* Panel A: OLS
areg final `control1', robust absorb(class) cluster(class)
outreg2 using table4_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ///
sortvar(pairmid nopair navgmid1_pair mid)
* Paenl B: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2', robust cluster(class) fe first
outreg2 using table4_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ///
sortvar(pairmid nopair navgmid1_pair mid)
* Panel B: To get the coefficient of constant term
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class, robust cluster(class)

*(4) Excluding pairs with the same major
set more off
use data0, clear
local control1 "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control2 "navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local ivs "tgpa ptgpa misstgpa missptgpa"

keep if major ~= pairmajor
* Panel A: OLS
areg final `control1', robust absorb(class) cluster(class)
outreg2 using table4_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4)
* Paenl B: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2', robust cluster(class) fe first
outreg2 using table4_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4)
* Panel B: To get the coefficient of constant term
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class, robust cluster(class)

*******************************************************************
* Table 5: SPeer Effects by Gender, Seat Row, Language, and Major *
*******************************************************************
set more off
use data0, clear
local control1 "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control2 "navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local ivs "tgpa ptgpa misstgpa missptgpa"

*(1) Boys
* Panel A: OLS
areg final `control1' if sex == 1, robust absorb(class) cluster(class)
outreg2 using table5_ols.xls, replace excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("boys")
* Panel B: 2SLS
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if sex == 1, robust cluster(class)
outreg2 using table5_iv.xls, replace excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("boys")

*(2) Girls
* Panel A: OLS
areg final `control1' if sex == 0, robust absorb(class) cluster(class)
outreg2 using table5_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("girls")
* Panel B: 2SLS
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if sex == 0, robust cluster(class)
outreg2 using table5_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("girls")

*(3) Up to 5th Rows
* Panel A: OLS
areg final `control1' if srow <= 5, robust absorb(class) cluster(class)
outreg2 using table5_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("1-4 rows")
* Panel B: 2SLS
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if srow <= 5, robust cluster(class)
outreg2 using table5_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("1-4 rows")

*(4) After 5th Rows
* Panel A: OLS
areg final `control1' if srow > 5, robust absorb(class) cluster(class)
outreg2 using table5_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("5+ rows")
* Panel B: 2SLS
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if srow > 5, robust cluster(class)
outreg2 using table5_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("5+ rows")

*(5) Class in English
* Panel A: OLS
areg final `control1' if english == 1, robust absorb(class) cluster(class)
outreg2 using table5_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("english")
* Panel B: 2SLS
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if english == 1, robust cluster(class)
outreg2 using table5_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("english")

*(6) Class in Korean
* Panel A: OLS
areg final `control1' if english == 0, robust absorb(class) cluster(class)
outreg2 using table5_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("korean")
* Panel B: 2SLS
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if english == 0, robust cluster(class)
outreg2 using table5_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("korean")

*(7) Economics Majors
* Panel A: OLS
areg final `control1' if major == 1, robust absorb(class) cluster(class)
outreg2 using table5_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("econ major")
* Panel B: 2SLS
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if major == 1, robust cluster(class)
outreg2 using table5_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("econ major")

*(8) Non-Economics Majors
* Panel A: OLS
areg final `control1' if major ~= 1, robust absorb(class) cluster(class)
outreg2 using table5_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("non-econ major") ///
sortvar(pairmid nopair navgmid1_pair mid)
* Panel B: 2SLS
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if major ~= 1, robust cluster(class)
outreg2 using table5_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("non-econ major") ///
sortvar(pairmid nopair navgmid1_pair hetsyear1 hetsex1 navgmid2 mid syear sex srow normcol  sidecol bus humsoc nateng retake exch)

*************************************************************************************************
* Table 6: Percentage (%) of Students with High MMPI Scores by Gender, Entering Year, and Major *
*************************************************************************************************
use data0, clear

keep if final ~= . & mid ~= . & pairmid ~= . & nopair ~= 1 & navgmid1_pair ~= . & pairHs ~= .

sum Hs D Hy Pd Mf Pa Pt Sc Ma Si

* By gender
sum Hs D Hy Pd Mf Pa Pt Sc Ma Si if sex == 1
sum Hs D Hy Pd Mf Pa Pt Sc Ma Si if sex == 0
* By entering year
sum Hs D Hy Pd Mf Pa Pt Sc Ma Si if enteryear == 2008
sum Hs D Hy Pd Mf Pa Pt Sc Ma Si if enteryear == 2009
sum Hs D Hy Pd Mf Pa Pt Sc Ma Si if enteryear == 2011
* By major
sum Hs D Hy Pd Mf Pa Pt Sc Ma Si if econ == 1
sum Hs D Hy Pd Mf Pa Pt Sc Ma Si if bus == 1
sum Hs D Hy Pd Mf Pa Pt Sc Ma Si if humsoc == 1
sum Hs D Hy Pd Mf Pa Pt Sc Ma Si if nateng == 1


****************************************
* Table 7: Peer Effects by Personality *
****************************************
set more off
local controls "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"

foreach type of varlist Hs D Hy Pd Mf Pa Pt Sc Ma Si {
use data0, clear

local mmpi "`type'"

keep if final ~= . & mid ~= . & pairmid ~= . & nopair ~= 1 & navgmid1_pair ~= . & pair`mmpi' ~= .

xtile social_own = `mmpi', nq(2)
xtile social_pair = pair`mmpi', nq(2)

areg final `controls' if social_own == 1 & social_pair == 1, robust cluster(class) absorb(class)
estimates store m1_`mmpi'

areg final `controls' if social_own == 1 & social_pair == 2, robust cluster(class) absorb(class)
estimates store m2_`mmpi'

areg final `controls' if social_own == 2 & social_pair == 1, robust cluster(class) absorb(class)
estimates store m3_`mmpi'

areg final `controls' if social_own == 2 & social_pair == 2, robust cluster(class) absorb(class)
estimates store m4_`mmpi'

}
esttab m1_Hs m2_Hs m3_Hs m4_Hs using table7.csv, replace cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1_D m2_D m3_D m4_D 	   using table7.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1_Hy m2_Hy m3_Hy m4_Hy using table7.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1_Pd m2_Pd m3_Pd m4_Pd using table7.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1_Mf m2_Mf m3_Mf m4_Mf using table7.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1_Pa m2_Pa m3_Pa m4_Pa using table7.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1_Pt m2_Pt m3_Pt m4_Pt using table7.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1_Sc m2_Sc m3_Sc m4_Sc using table7.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1_Ma m2_Ma m3_Ma m4_Ma using table7.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1_Si m2_Si m3_Si m4_Si using table7.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)


**************************************************************************
* Appendix Table 1: Instrumental Variable (IV) Estimates of Peer Effects *
**************************************************************************
set more off
use data0, clear
local control1 "tgpa ptgpa misstgpa missptgpa navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control2 "navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control3 "navgmid1_pair hetsex1 hetsyear1 sidecol syear sex retake exch bus humsoc nateng nopair"
local ivs "tgpa ptgpa misstgpa missptgpa"

*(1): Class FE
* Panel A
tsset class classentry
xi i.class
ivreg2 final (mid pairmid = `ivs') `control2' _Ic*, robust cluster(class)
outreg2 using table_a1.xls, replace excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("iv")

*(2): Row-by-Class FE
sort class_srow entry
tsset class_srow classentry1
xi i.class_srow, noomit
ivreg2 final (mid pairmid = `ivs') `control3'  _Iclass_sro_12 - _Iclass_sro_418 , robust cluster(class_srow)
outreg2 using table_a1.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("iv")

*(3): Students with pair
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if nopair == 0, robust cluster(class)
outreg2 using table_a1.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("ivs")

*(4): Adding tier-two peers
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' navgmid2 i.class, robust cluster(class)
outreg2 using table_a1.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("ivs") ///
sortvar(ptgpa tgpa pairmid nopair navgmid1_pair hetsyear1 hetsex1 navgmid2 mid syear sex srow normcol  sidecol bus humsoc nateng retake exch)

*********************************************************************************
* Appendix Table 2: Instrumental Variable Estimates of Peer Effects by Subgroup *
*********************************************************************************
set more off
estimate clear
use data0, clear
local control1 "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control2 "navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local ivs "tgpa ptgpa misstgpa missptgpa"

*(1) Boys
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if sex == 1, robust cluster(class)
outreg2 using table_a2.xls, replace excel label dec(3) nonot addstat(Adj. R-squared, e(ar2)) adec(3) ct("boys")

*(2) Girls
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if sex == 0, robust cluster(class)
outreg2 using table_a2.xls, append excel label dec(3) nonot addstat(Adj. R-squared, e(ar2)) adec(3) ct("girls")

*(3) Up to 5th Rows
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if srow <= 5, robust cluster(class)
outreg2 using table_a2.xls, append excel label dec(3) nonot addstat(Adj. R-squared, e(ar2)) adec(3) ct("1-4 rows")

*(4) After 5th Rows
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if srow > 5, robust cluster(class)
outreg2 using table_a2.xls, append excel label dec(3) nonot addstat(Adj. R-squared, e(ar2)) adec(3) ct("5+ rows")

*(5) Class in English
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if english == 1, robust cluster(class)
outreg2 using table_a2.xls, append excel label dec(3) nonot addstat(Adj. R-squared, e(ar2)) adec(3) ct("english")

*(6) Class in Korean
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if english == 0, robust cluster(class)
outreg2 using table_a2.xls, append excel label dec(3) nonot addstat(Adj. R-squared, e(ar2)) adec(3) ct("korean")

*(7) Economics Majors
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if major == 1, robust cluster(class)
outreg2 using table_a2.xls, append excel label dec(3) nonot addstat(Adj. R-squared, e(ar2)) adec(3) ct("econ major")

*(8) Non-Economics Majors
tsset class classentry
xi: ivreg2 final (mid pairmid = `ivs') `control2' i.class if major ~= 1, robust cluster(class)
outreg2 using table_a2.xls, append excel label dec(3) nonot addstat(Adj. R-squared, e(ar2)) adec(3) ct("non-econ major") ///
sortvar(pairmid nopair navgmid1_pair hetsyear1 hetsex1 navgmid2 mid syear sex srow normcol  sidecol bus humsoc nateng retake exch)


***********************************************************************
* Appendix Table 3. Estimates of the Peer Effect using Raw Test Score *
***********************************************************************
set more off

use data0, clear
for var final pairfinal mid pairmid navgfinal1_pair navgmid1_pair navgmid2: replace X = raw_X

local control1 "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control2 "navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local ivs "tgpa ptgpa misstgpa missptgpa"

* Panel A: Raw Test Score
preserve
replace pairmid = . if nopair == 1
sum final mid pairmid
sum final mid pairmid if sex == 1
sum final mid pairmid if sex == 0
sum final mid pairmid if srow <= 5
sum final mid pairmid if srow > 5
sum final mid pairmid if english == 1
sum final mid pairmid if english == 0
sum final mid pairmid if major == 1
sum final mid pairmid if major ~= 1
restore

*(1) All
* Panel B: OLS
areg final `control1', robust absorb(class) cluster(class)
outreg2 using table_a3_ols.xls, replace excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("All")
* Panel C: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2', robust cluster(class) fe first
outreg2 using table_a3_iv.xls, replace excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("All")

*(2) Boys
* Panel B: OLS
areg final `control1' if sex == 1, robust absorb(class) cluster(class)
outreg2 using table_a3_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("boys")
* Panel C: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2' if sex == 1, robust cluster(class) fe first
outreg2 using table_a3_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("boys")

*(3) Girls
* Panel B: OLS
areg final `control1' if sex == 0, robust absorb(class) cluster(class)
outreg2 using table_a3_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("girls")
* Panel C: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2' if sex == 0, robust cluster(class) fe first
outreg2 using table_a3_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("girls")

*(4) Up to 5th Rows
* Panel B: OLS
areg final `control1' if srow <= 5, robust absorb(class) cluster(class)
outreg2 using table_a3_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("1-4 rows")
* Panel C: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2' if srow <= 5, robust cluster(class) fe first
outreg2 using table_a3_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("1-4 rows")

*(5) After 5th Rows
* Panel B: OLS
areg final `control1' if srow > 5, robust absorb(class) cluster(class)
outreg2 using table_a3_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("5+ rows")
* Panel C: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2' if srow > 5, robust cluster(class) fe first
outreg2 using table_a3_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("5+ rows")

*(5) Class in English
* Panel B: OLS
areg final `control1' if english == 1, robust absorb(class) cluster(class)
outreg2 using table_a3_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("english")
* Panel C: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2' if english == 1, robust cluster(class) fe first
outreg2 using table_a3_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("english")

*(7) Class in Korean
* Panel B: OLS
areg final `control1' if english == 0, robust absorb(class) cluster(class)
outreg2 using table_a3_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("korean")
* Panel C: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2' if english == 0, robust cluster(class) fe first
outreg2 using table_a3_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("korean")

*(8) Economics Majors
* Panel B: OLS
areg final `control1' if major == 1, robust absorb(class) cluster(class)
outreg2 using table_a3_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("econ major")
* Panel C: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2' if major == 1, robust cluster(class) fe first
outreg2 using table_a3_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("econ major")

*(9) Non-Economics Majors
* Panel B: OLS
areg final `control1' if major ~= 1, robust absorb(class) cluster(class)
outreg2 using table_a3_ols.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("non-econ major") ///
sortvar(pairmid nopair navgmid1_pair mid)
* Panel C: 2SLS
tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2' if major ~= 1, robust cluster(class) fe first
outreg2 using table_a3_iv.xls, append excel label dec(4) nonot addstat(Adj. R-squared, e(ar2)) adec(4) ct("non-econ major")


***********************************************************************
* Appendix Table 4: Alternative Definitions of Social/Unsocial Groups *
***********************************************************************
set more off
estimates clear

* (1)-(4): Cutoff of high MMPI score: > 70 - OLS 
use data0, clear

foreach mmpi of varlist Hs Pd Sc Ma Si {
use data0, clear
local controls "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
keep if final ~= . & mid ~= . & pairmid ~= . & nopair ~= 1 & navgmid1_pair ~= . & pair`mmpi' ~= .

xtile social_own = `mmpi', nq(2)
xtile social_pair = pair`mmpi', nq(2)

areg final `controls' if social_own == 1  & social_pair == 1, robust cluster(class) absorb(class)
estimates store m11_`mmpi'
areg final `controls' if social_own == 1 & social_pair == 2, robust cluster(class) absorb(class)
estimates store m12_`mmpi'
areg final `controls' if social_own == 2 & social_pair == 1, robust cluster(class) absorb(class)
estimates store m13_`mmpi'
areg final `controls' if social_own == 2 & social_pair == 2, robust cluster(class) absorb(class)
estimates store m14_`mmpi'
}

* (1)-(4): Cutoff of high MMPI score: > 70 - IV
foreach mmpi of varlist Hs Pd Sc Ma Si {
use data0, clear

local control1 "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control2 "navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local ivs "tgpa ptgpa misstgpa missptgpa"
keep if final ~= . & mid ~= . & pairmid ~= . & nopair ~= 1 & navgmid1_pair ~= . & pair`mmpi' ~= .

xtile social_own = `mmpi', nq(2)
xtile social_pair = pair`mmpi', nq(2)


tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2' if social_own == 1  & social_pair == 1, robust cluster(class) fe
estimates store m21_`mmpi'
xtivreg2 final (mid pairmid = `ivs') `control2' if social_own == 1  & social_pair == 2, robust cluster(class) fe
estimates store m22_`mmpi'
xtivreg2 final (mid pairmid = `ivs') `control2' if social_own == 2  & social_pair == 1, robust cluster(class) fe
estimates store m23_`mmpi'
xtivreg2 final (mid pairmid = `ivs') `control2' if social_own == 2  & social_pair == 2, robust cluster(class) fe
estimates store m24_`mmpi'
}


* (5)-(8): Cutoff of high MMPI score: > 60 - OLS 
foreach mmpi of varlist Hs Pd Sc Ma Si {
use data0, clear
for var Hs D Hy Pd Mf Pa Pt Sc Ma Si pairHs pairD pairHy pairPd pairMf pairPa pairPt pairSc pairMa pairSi: replace X = X_60

local controls "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
keep if final ~= . & mid ~= . & pairmid ~= . & nopair ~= 1 & navgmid1_pair ~= . & pair`mmpi' ~= .

xtile social_own = `mmpi', nq(2)
xtile social_pair = pair`mmpi', nq(2)

areg final `controls' if social_own == 1  & social_pair == 1, robust cluster(class) absorb(class)
estimates store m15_`mmpi'
areg final `controls' if social_own == 1 & social_pair == 2, robust cluster(class) absorb(class)
estimates store m16_`mmpi'
areg final `controls' if social_own == 2 & social_pair == 1, robust cluster(class) absorb(class)
estimates store m17_`mmpi'
areg final `controls' if social_own == 2 & social_pair == 2, robust cluster(class) absorb(class)
estimates store m18_`mmpi'
}

* (5)-(8): Cutoff of high MMPI score: > 60 - IV
foreach mmpi of varlist Hs Pd Sc Ma Si {
use data0, clear
for var Hs D Hy Pd Mf Pa Pt Sc Ma Si pairHs pairD pairHy pairPd pairMf pairPa pairPt pairSc pairMa pairSi: replace X = X_60

local control1 "mid pairmid navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local control2 "navgmid1_pair hetsex1 hetsyear1 srow sidecol syear sex retake exch bus humsoc nateng nopair"
local ivs "tgpa ptgpa misstgpa missptgpa"
keep if final ~= . & mid ~= . & pairmid ~= . & nopair ~= 1 & navgmid1_pair ~= . & pair`mmpi' ~= .

xtile social_own = `mmpi', nq(2)
xtile social_pair = pair`mmpi', nq(2)


tsset class classentry
xtivreg2 final (mid pairmid = `ivs') `control2' if social_own == 1  & social_pair == 1, robust cluster(class) fe
estimates store m25_`mmpi'
xtivreg2 final (mid pairmid = `ivs') `control2' if social_own == 1  & social_pair == 2, robust cluster(class) fe
estimates store m26_`mmpi'
xtivreg2 final (mid pairmid = `ivs') `control2' if social_own == 2  & social_pair == 1, robust cluster(class) fe
estimates store m27_`mmpi'
xtivreg2 final (mid pairmid = `ivs') `control2' if social_own == 2  & social_pair == 2, robust cluster(class) fe
estimates store m28_`mmpi'
}


esttab m1*_Hs using table_a4.csv, replace  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m2*_Hs using table_a4.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1*_Pd using table_a4.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m2*_Pd using table_a4.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1*_Sc using table_a4.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m2*_Sc using table_a4.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1*_Ma using table_a4.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m2*_Ma using table_a4.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m1*_Si using table_a4.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)
esttab m2*_Si using table_a4.csv, append  cells(b(star fmt(4)) se(par fmt(4))) keep( pairmid) starlevels(* 0.10 ** 0.05 *** 0.01)


**************************************
* Figures 2, 3 and Appendix Figure 2 *
**************************************
clear
set more off

use quantile_regression.dta, clear
keep if sample == "all"

gen qt = _n
gen y = 0

* Graph: Pair Mid
graph twoway (rarea ivqr_pmid_c0 ivqr_pmid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_pmid_est qt, lc(gs0)) ///
			 (line qr_pmid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig1, replace) ///
xlabel(10(10)90) ylabel(-0.2 (0.2) 0.4) xtitle("Quantile") ytitle("Coefficient") legend(off) yline(0, lc(gs3)) ///
title("Pair's Midterm")

* Graph: Own Mid
graph twoway (rarea ivqr_mid_c0 ivqr_mid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_mid_est qt, lc(gs0)) ///
			 (line qr_mid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig2, replace) ///
xlabel(10(10)90) xtitle("Quantile") ytitle("Coefficient") yline(0, lc(gs3)) ///
title("Own Midterm") ///
legend(region(lcolor(none)) ring(0) pos(1) cols(1) lab(1 "IVQR 90% Conf. Interval") lab(2 "IVQR Coeff.") lab(3 "QR Coeff.") order(1 2 3))

**************************************************************************
* Figure 2: Instrumental Variable Quantile Regression Estimation Results *
**************************************************************************
graph combine fig1.gph fig2.gph, cols(2)

* Male
use quantile_regression.dta, clear
keep if sample == "male"
gen qt = _n
gen y = 0
drop if qt<10 | qt>90

graph twoway (rarea ivqr_pmid_c0 ivqr_pmid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_pmid_est qt, lc(gs0)) ///
			 (line qr_pmid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig1_male, replace) ///
xlabel(10(10)90) ylabel(-0.5 0(0.5)1) xtitle("Quantile") ytitle("Coefficient") legend(off) yline(0, lc(gs3)) ///
title("Boys")

graph twoway (rarea ivqr_mid_c0 ivqr_mid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_mid_est qt, lc(gs0)) ///
			 (line qr_mid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig2_male, replace) ///
xlabel(10(10)90) xtitle("Quantile") ytitle("Coefficient") yline(0, lc(gs3)) ///
title("Boys") legend(off)

* Female
use quantile_regression.dta, clear
keep if sample == "female"
gen qt = _n
gen y = 0
drop if qt<10 | qt>90

graph twoway (rarea ivqr_pmid_c0 ivqr_pmid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_pmid_est qt, lc(gs0)) ///
			 (line qr_pmid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig1_female, replace) ///
xlabel(10(10)90) ylabel(-0.5 0(0.5)1) xtitle("Quantile") ytitle("Coefficient") legend(off) yline(0, lc(gs3)) ///
title("Girls")

graph twoway (rarea ivqr_mid_c0 ivqr_mid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_mid_est qt, lc(gs0)) ///
			 (line qr_mid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig2_female, replace) ///
xlabel(10(10)90) xtitle("Quantile") ytitle("Coefficient") yline(0, lc(gs3)) ///
title("Girls") legend(off)


graph combine fig1_male.gph fig1_female.gph, cols(2)
graph display, xsize(10) ysize(6) scale(1.3)

* Front
set more off
use quantile_regression.dta, clear
keep if sample == "front"
gen qt = _n
gen y = 0
drop if qt<10 | qt>90

graph twoway (rarea ivqr_pmid_c0 ivqr_pmid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_pmid_est qt, lc(gs0)) ///
			 (line qr_pmid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig1_front, replace) ///
xlabel(10(10)90) ylabel(-0.4 0(0.5)1) xtitle("Quantile") ytitle("Coefficient") legend(off) yline(0, lc(gs3)) ///
title("Front Rows")

graph twoway (rarea ivqr_mid_c0 ivqr_mid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_mid_est qt, lc(gs0)) ///
			 (line qr_mid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig2_front, replace) ///
xlabel(10(10)90) xtitle("Quantile") ytitle("Coefficient") yline(0, lc(gs3)) ///
title("Front Rows") legend(off)

* Rear
use quantile_regression.dta, clear
keep if sample == "rear"
gen qt = _n
gen y = 0
drop if qt<10 | qt>90

graph twoway (rarea ivqr_mid_c0 ivqr_mid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_mid_est qt, lc(gs0)) ///
			 (line qr_mid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig2_rear, replace) ///
xlabel(10(10)90) xtitle("Quantile") ytitle("Coefficient") yline(0, lc(gs3)) ///
title("Rear Rows") legend(off)

for var ivqr_mid_c0 - qr_pmid_se: replace X=1 if X>=1
for var ivqr_mid_c0 - qr_pmid_se: replace X=-0.5 if X<=-0.5

graph twoway (rarea ivqr_pmid_c0 ivqr_pmid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_pmid_est qt, lc(gs0)) ///
			 (line qr_pmid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig1_rear, replace) ///
xlabel(10(10)90)  ylabel(-0.4 0(0.5)1) xtitle("Quantile") ytitle("Coefficient") legend(off) yline(0, lc(gs3)) ///
title("Rear Rows")

graph combine fig1_front.gph fig1_rear.gph, cols(2)
graph display, xsize(10) ysize(6) scale(1.3)

* English
use quantile_regression.dta, clear
keep if sample == "english"
gen qt = _n
gen y = 0
drop if qt<10 | qt>90

graph twoway (rarea ivqr_pmid_c0 ivqr_pmid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_pmid_est qt, lc(gs0)) ///
			 (line qr_pmid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig1_eng, replace) ///
xlabel(10(10)90) ylabel(-0.3 0 (0.5)2.5) xtitle("Quantile") ytitle("Coefficient") legend(off) yline(0, lc(gs3)) ///
title("Class in English")

graph twoway (rarea ivqr_mid_c0 ivqr_mid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_mid_est qt, lc(gs0)) ///
			 (line qr_mid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig2_eng, replace) ///
xlabel(10(10)90) xtitle("Quantile") ytitle("Coefficient") yline(0, lc(gs3)) ///
title("Class in English") legend(off)

* Korean
use quantile_regression.dta, clear
keep if sample == "korean"
gen qt = _n
gen y = 0
drop if qt<10 | qt>90

graph twoway (rarea ivqr_pmid_c0 ivqr_pmid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_pmid_est qt, lc(gs0)) ///
			 (line qr_pmid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig1_kor, replace) ///
xlabel(10(10)90)   xtitle("Quantile") ytitle("Coefficient") legend(off) yline(0, lc(gs3)) ///
title("Class in Korean")

graph twoway (rarea ivqr_mid_c0 ivqr_mid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_mid_est qt, lc(gs0)) ///
			 (line qr_mid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig2_kor, replace) ///
xlabel(10(10)90) xtitle("Quantile") ytitle("Coefficient") yline(0, lc(gs3)) ///
title("Class in Korean") legend(off)

graph combine fig1_eng.gph fig1_kor.gph, cols(2)
graph display, xsize(10) ysize(6) scale(1.3)


* Econ
use quantile_regression.dta, clear
keep if sample == "econ"
gen qt = _n
gen y = 0
drop if qt<10 | qt>90

graph twoway (rarea ivqr_mid_c0 ivqr_mid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_mid_est qt, lc(gs0)) ///
			 (line qr_mid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig2_econ, replace) ///
xlabel(10(10)90) xtitle("Quantile") ytitle("Coefficient") yline(0, lc(gs3)) ///
title("Major in Economics") legend(off)

for var ivqr_mid_c0 - qr_pmid_se: replace X=0.8 if X>=0.8
for var ivqr_mid_c0 - qr_pmid_se: replace X=-0.5 if X<=-0.5

graph twoway (rarea ivqr_pmid_c0 ivqr_pmid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_pmid_est qt, lc(gs0)) ///
			 (line qr_pmid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig1_econ, replace) ///
xlabel(10(10)90) ylabel(-0.3 0 0.4 0.8)  xtitle("Quantile") ytitle("Coefficient") legend(off) yline(0, lc(gs3)) ///
title("Major in Economics")

* Non-Econ
use quantile_regression.dta, clear
keep if sample == "nonecon"
gen qt = _n
gen y = 0
drop if qt<10 | qt>90

graph twoway (rarea ivqr_mid_c0 ivqr_mid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_mid_est qt, lc(gs0)) ///
			 (line qr_mid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig2_nonecon, replace) ///
xlabel(10(10)90) xtitle("Quantile") ytitle("Coefficient") yline(0, lc(gs3)) ///
title("Major in Non-Economics") legend(off)

for var ivqr_mid_c0 - qr_pmid_se: replace X=1 if X>=1
for var ivqr_mid_c0 - qr_pmid_se: replace X=-0.5 if X<=-0.5

graph twoway (rarea ivqr_pmid_c0 ivqr_pmid_c1 qt, col(gs10) fi(inten20)) ///
			 (line ivqr_pmid_est qt, lc(gs0)) ///
			 (line qr_pmid_est qt, lc(gs5) lp(dash)) ///
			 (line y qt, lc(gs3) lp(solid)), saving(fig1_nonecon, replace) ///
xlabel(10(10)90) ylabel(-0.3 0 0.4 0.8)  xtitle("Quantile") ytitle("Coefficient") legend(off) yline(0, lc(gs3)) ///
title("Major in Non-Economics")

graph combine fig1_econ.gph fig1_nonecon.gph, cols(2)
graph display, xsize(10) ysize(6) scale(1.3)

***************************************************************************************
* Figure 3: Instrumental Variable Quantile Regression Estimation Results by Subsample *
***************************************************************************************
graph combine fig1_male.gph fig1_female.gph ///
			  fig1_front.gph fig1_rear.gph ///
			  fig1_eng.gph fig1_kor.gph ///
			  fig1_econ.gph fig1_nonecon.gph, cols(2)
graph display, xsize(10) ysize(15)


****************************************************************************************************************************
* Appendix Figure 2: Instrumental Variable Quantile Regression Estimation by Subsample: Coefficients of Own Midterm Scores *
****************************************************************************************************************************
graph combine fig2_male.gph fig2_female.gph ///
			  fig2_front.gph fig2_rear.gph ///
			  fig2_eng.gph fig2_kor.gph ///
			  fig2_econ.gph fig2_nonecon.gph, cols(2)
graph display, xsize(10) ysize(15)

log close
