function [b,vc,g,vc_g,J_t] = kcov_iqr(beta,gamma,tau,y,d,x,z,kernel,h,A)
% [b,vc,g,vc_g] = kcov_iqr(beta,tau,y,d,x,z,kernel,h,A)
% Calculates the heteroskedasticity consistent variance-covariance
%   matrix for inverse quantile regression estimates using kernel methods
%   as introduced in Powell (1984) and Buchinsky (1995).
% Output --
%   b - coefficient vector and standard errors
%       If betas for more than one quantile are passed, the odd rows
%       are the coefficient estimates and the even rows are the standard
%       errors.
%   vc - the complete variance-covariance matrix
%       If more than one quantile is passed this is the variance-covariance
%       matrix of the joint distribution for all of the quantiles passed.
%   g - gamma vector with standard errors.  Output formatted as b.
%   NOTE:  To skip calculation of standard errors for gamma (or if equation
%          is just identified) pass gamma = [].
%   vc_g - as vc but for gammas
%   NOTE:  Covariance between betas and gammas is not reported.
%
% Input --
%   beta - coefficient estimates from IQR.  Estimates from more than one
%          quantile may be passed.  Each column should contain the estimates
%          for one quantile.
%   gamma - coefficients on instruments in IQR.  Estimates from more than
%          one quantile may be passed.  Each column should contain the estimates
%          for one quantile.  If the system is just identified or standard
%          errors for gamma are not required, pass gamma = [];
%   tau - row vector containing the quantile index of each column of beta/gamma
%   y - observations on dependent variable (n X 1)
%   d - observations on endogenous variables (n X s);
%   x - observations on covariates (n X k)
%   NOTE:  Do not include a constant with x.
%   z - observations on excluded instruments (n X r);
%   NOTE:  The last three arguments are optional.  Failure to specify them
%          will result in the use of default options, as will passing [].
%   kernel - 0 -- uniform kernel
%          - 1 -- gaussian kernel (default)
%   h - bandwidth
%          - 0 -- Plug-in method based on interquartile range (default)
%          - -1 -- Silverman's rule of thumb
%   A - weighting matrix
%          - 1 -- Estimates were formed using optimal weighting matrix.
%          - [] -- Estimates were formed using optimal weighting matrix under
%                  iid error structure (default)


if size(beta,2) ~= size(tau,2),
    error('Beta and tau incompatible')
end

if nargin == 7,
    kernel = [];
    h = [];
    A = [];
elseif nargin == 8,
    h = [];
    A = [];
elseif nargin == 9,
    A = [];
end

if isempty(kernel),
    kernel = 1;
end

x = [x,ones(size(y))];
n = size(y,1);


vc = zeros(size(beta,1)*size(tau,2),size(beta,1)*size(tau,2));

for i = 1:size(tau,2),
    for j = i:size(tau,2),
        if i~=j,
            e1 = y - [d,x]*beta(:,i);
            e2 = y - [d,x]*beta(:,j);
            J1 = J(e1,[d,x],[x,z],kernel,h);
            J2 = J(e2,[d,x],[x,z],kernel,h);
            [K1,JT1] = K(e1,x,z,kernel,h,A);
            [K2,JT2] = K(e2,x,z,kernel,h,A);
            S = (1/n)*[x,z]'*[x,z];
            G1 = inv(J1*inv(K1)*J1');
            G2 = inv(J2*inv(K2)*J2');
            H = J1*inv(K1)*S*inv(K2)*J2';
            vc(size(beta,1)*(i-1)+1:size(beta,1)*i, ...
               size(beta,1)*(j-1)+1:size(beta,1)*j) = ...
               (1/n)*(min(tau(1,i),tau(1,j))-tau(1,i)*tau(1,j))*G1*H*G2;
            vc(size(beta,1)*(j-1)+1:size(beta,1)*j, ...
               size(beta,1)*(i-1)+1:size(beta,1)*i) = ...
               (1/n)*(min(tau(1,i),tau(1,j))-tau(1,i)*tau(1,j))*G2'*H'*G1';
            if isempty(gamma),
                g = [];
                vc_g = [];
            else,
                IJT1 = inv(JT1);
                C1 = IJT1(size(x,2)+1:size(JT1,2),:)*(eye(size(z,2)) ...
                       - [J1(1:size(d,2),:)]'*inv([J1(1:size(d,2),:)]* ...
                         (inv(K1)-[inv(JT1(1:size(x,2),1:size(x,2))) zeros(size(x,2),size(z,2)); ...
                                   zeros(size(z,2),size(x,2)) zeros(size(z,2),size(z,2))])* ...
                         [J1(1:size(d,2),:)]')*[J1(1:size(d,2),:)]* ...
                         (inv(K1)-[inv(JT1(1:size(x,2),1:size(x,2))) zeros(size(x,2),size(z,2)); ...
                                   zeros(size(z,2),size(x,2)) zeros(size(z,2),size(z,2))]));
                IJT2 = inv(JT2);
                C2 = IJT2(size(x,2)+1:size(JT2,2),:)*(eye(size(z,2)) ...
                       - [J2(1:size(d,2),:)]'*inv([J2(1:size(d,2),:)]* ...
                         (inv(K2)-[inv(JT2(1:size(x,2),1:size(x,2))) zeros(size(x,2),size(z,2)); ...
                                   zeros(size(z,2),size(x,2)) zeros(size(z,2),size(z,2))])* ...
                         [J2(1:size(d,2),:)]')*[J2(1:size(d,2),:)]* ...
                         (inv(K2)-[inv(JT2(1:size(x,2),1:size(x,2))) zeros(size(x,2),size(z,2)); ...
                                   zeros(size(z,2),size(x,2)) zeros(size(z,2),size(z,2))]));
                vc_g(size(gamma,1)*(i-1)+1:size(gamma,1)*i, ...
                     size(gamma,1)*(j-1)+1:size(gamma,1)*j) = ...
                     (1/n)*(min(tau(1,i),tau(1,j))-tau(1,i)*tau(1,j))*C1*S*C2';
                vc_g(size(gamma,1)*(j-1)+1:size(gamma,1)*j, ...
                     size(gamma,1)*(i-1)+1:size(gamma,1)*i) = ...
                     (1/n)*(min(tau(1,i),tau(1,j))-tau(1,i)*tau(1,j))*C2*S*C1';
            end
        else,
            e = y - [d,x]*beta(:,i);
            J = J(e,[d,x],[x,z],kernel,h);
            [K,JT] = K(e,x,z,kernel,h,A);
            S = (1/n)*[x,z]'*[x,z];
            G = inv(J*inv(K)*J');
            H = J*inv(K)*S*inv(K)*J';
            vc(size(beta,1)*(i-1)+1:size(beta,1)*i, ...
               size(beta,1)*(i-1)+1:size(beta,1)*i) = ...
               (1/n)*(tau(1,i)-tau(1,i)^2)*G*H*G;
            b(:,2*i-1) = beta(:,i);
            b(:,2*i) = sqrt(diag(vc(size(beta,1)*(i-1)+1:size(beta,1)*i, ...
                               size(beta,1)*(i-1)+1:size(beta,1)*i)));
            if isempty(gamma),
                g = [];
                vc_g = [];
            else,
                IJT = inv(JT);
                C = IJT(size(x,2)+1:size(JT,2),:)*(eye(size(z,2)) ...
                        - [J(1:size(d,2),:)]'*inv([J(1:size(d,2),:)]* ...
                          (inv(K)-[inv(JT(1:size(x,2),1:size(x,2))) zeros(size(x,2),size(z,2)); ...
                                   zeros(size(z,2),size(x,2)) zeros(size(z,2),size(z,2))])* ...
                          [J(1:size(d,2),:)]')*[J(1:size(d,2),:)]* ...
                          (inv(K)-[inv(JT(1:size(x,2),1:size(x,2))) zeros(size(x,2),size(z,2)); ...
                                   zeros(size(z,2),size(x,2)) zeros(size(z,2),size(z,2))]));
                vc_g(size(gamma,1)*(i-1)+1:size(gamma,1)*i, ... 
                     size(gamma,1)*(i-1)+1:size(gamma,1)*i) = ...
                     (1/n)*(tau(1,i)-tau(1,i)^2)*C*S*C';
                g(:,2*i-1) = gamma(:,i);
                g(:,2*i) = sqrt(diag(vc_g(size(gamma,1)*(i-1)+1:size(gamma,1)*i, ...
                                     size(gamma,1)*(i-1)+1:size(gamma,1)*i)));
            end
            J_t(:,:,i) = JT;
        end      
    end
end



function f = J(e,w,psi,kernel,h)

n = size(e,1);

if kernel == 1, %Gaussian kernel
    
    if isempty(h) | h==0,
        h = iqr(e)*(n^(-2/5));   % Plug-in method used in Morillo's ox code
                               % for Koenker & Portnoy (1997)
    elseif h < 0,
        h = 1.364*((2*sqrt(pi))^(-1/5))*std(e)*(n^(-1/5));
                               % Silverman's rule of thumb -- Silverman (1986)
                               % in Hardle & Linton (1994)
    end
    
    f = (1/(n*h))*((normpdf(e/h)*ones(1,size(w,2))).*w)'*psi;
    
elseif kernel == 0, %Uniform kernel
    
    if isempty(h) | h==0,
        h = 1.740*iqr(e)*(n^(-2/5));    % Plug-in from Morillo adjusted for 
                                      % uniform kernel
    elseif h < 0,
        h = 1.364*((9/2)^(1/5))*std(e)*(n^(-1/5));
                                        % Silverman's rule of thumb    
    end
        
    f = (1/(n*h))*(((1/2)*(abs(e)<=h)*ones(1,size(w,2))).*w)'*psi;
    
end


function [g,J_t] = K(e,x,z,kernel,h,A)

n = size(e,1);

if isempty(A),
    A = (z'*z) - (z'*x)*(inv(x'*x))*(x'*z);
end

psi = [x,z];

if kernel == 1, %Gaussian kernel
    
    if isempty(h) | h==0,
        h = iqr(e)*(n^(-2/5));   % Plug-in method used in Morillo's ox code
                               % for Koenker & Portnoy (1997)
    elseif h < 0,
        h = 1.364*((2*sqrt(pi))^(-1/5))*std(e)*(n^(-1/5));
                               % Silverman's rule of thumb -- Silverman (1986)
                               % in Hardle & Linton (1994)
    end
    
    J_t = (1/(n*h))*((normpdf(e/h)*ones(1,size(psi,2))).*psi)'*psi;
    
    if A == 1,
        g = J_t;
    else,
        invJ_t = inv(J_t);
        F22 = invJ_t(size(x,2)+1:size(J_t,1),size(x,2)+1:size(J_t,1));
        Jbb = J_t(1:size(x,2),1:size(x,2));
        Jxz = J_t(1:size(x,2),size(x,2)+1:size(J_t,1));
        Kx = [Jbb , Jxz];
        Kz = [Jxz', inv(F22*A*F22) + Jxz'*inv(Jbb)*Jxz];
        g = [Kx ; Kz];
    end
        
elseif kernel == 0, %Uniform kernel
    
    if isempty(h) | h==0,
        h = 1.740*iqr(e)*(n^(-2/5));    % Plug-in from Morillo adjusted for 
                                      % uniform kernel
    elseif h < 0,
        h = 1.364*((9/2)^(1/5))*std(e)*(n^(-1/5));
                                        % Silverman's rule of thumb    
    end
        
    J_t = (1/(n*h))*(((1/2)*(abs(e)<=h)*ones(1,size(psi,2))).*psi)'*psi;

    if A == 1,
        g = J_t;
    else,
        invJ_t = inv(J_t);
        F22 = invJ_t(size(x,2)+1:size(J_t,1),size(x,2)+1:size(J_t,1));
        Jbb = J_t(1:size(x,2),1:size(x,2));
        Jxz = J_t(1:size(x,2),size(x,2)+1:size(J_t,1));
        Kx = [Jbb , Jxz];
        Kz = [Jxz', inv(F22*A*F22) + Jxz'*inv(Jbb)*Jxz];
        g = [Kx ; Kz];
    end

end
